@@ -94,9 +94,9 @@ def test_map_embeddings():
     map = project.get_map(name='UNITTEST1')
 
     project.create_index(name='My new index')
-    # time.sleep(5)
-    # result = map._get_nearest_neighbors(queries=np.random.rand(1, 10), k=2)
-    # assert len(result['neighbors'][0]) == 2
+    with project.wait_for_project_lock():
+        neighbors, _ = map.vector_search(queries=np.random.rand(1, 10), k=2)
+        assert len(neighbors[0]) == 2
 
     for map in project.projections:
         assert map.map_link
